@@ -517,7 +517,7 @@ impl std::fmt::Display for Error {
     }
 }
 
-#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
+#[derive(Debug, Eq, PartialEq, Copy, Clone, Serialize, Deserialize)]
 pub struct IEID(u64, u64);
 
 impl IEID {
