@@ -205,6 +205,10 @@ impl Initial {
         self.config.as_ref()
     }
     #[inline]
+    pub fn workers(&self) -> u32 {
+        self.workers
+    }
+    #[inline]
     pub fn elbus_queue_size(&self) -> usize {
         self.bus.queue_size
     }
