@@ -360,6 +360,33 @@ impl Value {
         }
     }
 
+    pub fn to_string_or_pack(self) -> EResult<String> {
+        match self {
+            Value::U8(v) => Ok(v.to_string()),
+            Value::U16(v) => Ok(v.to_string()),
+            Value::U32(v) => Ok(v.to_string()),
+            Value::U64(v) => Ok(v.to_string()),
+            Value::I8(v) => Ok(v.to_string()),
+            Value::I16(v) => Ok(v.to_string()),
+            Value::I32(v) => Ok(v.to_string()),
+            Value::I64(v) => Ok(v.to_string()),
+            Value::F32(v) => Ok(v.to_string()),
+            Value::F64(v) => Ok(v.to_string()),
+            Value::Char(v) => Ok(v.to_string()),
+            Value::String(v) => Ok(v),
+            _ => Ok(format!("!!{}", serde_json::to_string(&self)?)),
+        }
+    }
+
+    pub fn unpack(self) -> EResult<Self> {
+        if let Value::String(ref v) = self {
+            if let Some(s) = v.strip_prefix("!!") {
+                return serde_json::from_str(s).map_err(Into::into);
+            }
+        }
+        Ok(self)
+    }
+
     fn discriminant(&self) -> usize {
         match *self {
             Value::Bool(..) => 0,
@@ -1292,3 +1319,31 @@ impl TryFrom<serde_json::Value> for Value {
         serde_json::from_value(v).map_err(Into::into)
     }
 }
+
+#[cfg(test)]
+mod test {
+    use crate::prelude::*;
+    use serde::Serialize;
+
+    #[test]
+    fn test_val_pack() -> EResult<()> {
+        #[derive(Serialize)]
+        struct My {
+            test: bool,
+            abc: usize,
+        }
+
+        let my = My {
+            test: true,
+            abc: 123,
+        };
+        let mut valx: Value = to_value(my)?;
+        valx = valx.unpack()?;
+        let vlstr = valx.clone().to_string_or_pack()?;
+        dbg!(&vlstr);
+        let mut val = Value::String(vlstr);
+        val = val.unpack()?;
+        assert_eq!(val, valx);
+        Ok(())
+    }
+}
